
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class CoinRecordModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None):
        super(CoinRecordModel, self).__init__(CoinRecord, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class CoinRecord:

    def __init__(self):
        super(CoinRecord, self).__init__()
        self.id = 0  # id
        self.act_id = 0  # act_id
        self.user_id = 0  # user_id
        self.title = ""  # 标题
        self.change_type = 0  # 变动类型:1手动2每日任务3每周任务4兑换
        self.transaction_type = 0  # 交易类型:1增加2减少
        self.coin_count = 0  # T币数量
        self.history_coin_count = 0  # 历史T币数量
        self.operation_user_id = ""  # 操作用户id
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'act_id', 'user_id', 'title', 'change_type', 'transaction_type', 'coin_count', 'history_coin_count', 'operation_user_id', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "coin_record_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class UserInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None):
        super(UserInfoModel, self).__init__(UserInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class UserInfo:

    def __init__(self):
        super(UserInfo, self).__init__()
        self.id = 0  # id
        self.act_id = 0  # act_id
        self.open_id = ""  # open_id
        self.union_id = ""  # UnionID
        self.user_nick = ""  # 用户昵称
        self.user_nick_base64 = ""  # 用户昵称Base64
        self.avatar = ""  # 头像
        self.e_mail = ""  # 邮箱
        self.is_new = 0  # 是否新用户
        self.telephone = ""  # 手机号
        self.gender = 0  # 性别:1男 2女
        self.age = 0  # 年龄
        self.birthday = "1900-01-01 00:00:00"  # 生日
        self.province = ""  # 省
        self.city = ""  # 市
        self.county = ""  # 区
        self.last_ip = ""  # 最后登录IP
        self.pay_price = 0  # 累计支付金额
        self.pay_num = 0  # 累计支付笔数
        self.removed_count = 0  # 已拆次数
        self.login_token = ""  # 登录令牌
        self.signin = ""  # 签到信息
        self.surplus_coin = 0  # 剩余T币
        self.tips_card_count = 0  # 提示卡数量
        self.perspective_card_count = 0  # 透视卡数量
        self.redraw_card_count = 0  # 重抽卡数量
        self.user_state = 0  # 用户状态（0-正常，1-黑名单）
        self.relieve_date = "1900-01-01 00:00:00"  # 解禁时间
        self.last_login_date = "1900-01-01 00:00:00"  # 最后登录时间
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'act_id', 'open_id', 'union_id', 'user_nick', 'user_nick_base64', 'avatar', 'e_mail', 'is_new', 'telephone', 'gender', 'age', 'birthday', 'province', 'city', 'county', 'last_ip', 'pay_price', 'pay_num', 'removed_count', 'login_token', 'signin', 'surplus_coin', 'tips_card_count', 'perspective_card_count', 'redraw_card_count', 'user_state', 'relieve_date', 'last_login_date', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "user_info_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PrizeOrderModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None):
        super(PrizeOrderModel, self).__init__(PrizeOrder, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class PrizeOrder:

    def __init__(self):
        super(PrizeOrder, self).__init__()
        self.id = 0  # id
        self.order_no = ""  # 订单号
        self.act_id = 0  # act_id
        self.user_id = 0  # user_id
        self.real_name = ""  # 真实姓名
        self.telephone = ""  # 手机号码
        self.province = ""  # 所在省
        self.city = ""  # 所在市
        self.county = ""  # 所在区
        self.street = ""  # 所在街道
        self.adress = ""  # 收货地址
        self.deliver_date = "1900-01-01 00:00:00"  # 发货时间
        self.express_no = ""  # 快递单号
        self.express_company = ""  # 快递公司
        self.order_status = 0  # 订单状态（0未付款1未发货2已发货3不予发货4已退款5已完成10付款中）
        self.is_auto_deliver = 0  # 是否自动发货：0否1是
        self.freight_price = 0  # 运费价格
        self.is_free_shipping = 0  # 是否包邮
        self.freight_pay_order_no = ""  # 运费支付订单id
        self.remarks = ""  # 备注
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'order_no', 'act_id', 'user_id', 'real_name', 'telephone', 'province', 'city', 'county', 'street', 'adress', 'deliver_date', 'express_no', 'express_company', 'order_status', 'is_auto_deliver', 'freight_price', 'is_free_shipping', 'freight_pay_order_no', 'remarks', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "prize_order_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class SignRecordModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None):
        super(SignRecordModel, self).__init__(SignRecord, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class SignRecord:

    def __init__(self):
        super(SignRecord, self).__init__()
        self.id = 0  # id
        self.act_id = 0  # act_id
        self.user_id = 0  # user_id
        self.current_week = 0  # 当前第几周
        self.reward_coin_count = 0  # 奖励T币数量
        self.history_coin_count = 0  # 历史T币数量
        self.sign_date_int = 0  # 签到时间整形(yyyymmdd)
        self.sign_date = "1900-01-01 00:00:00"  # 签到时间

    @classmethod
    def get_field_list(self):
        return ['id', 'act_id', 'user_id', 'current_week', 'reward_coin_count', 'history_coin_count', 'sign_date_int', 'sign_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "sign_record_tb"
    


# -*- coding: utf-8 -*-
"""
@Author: WangQiang
@Date: 2021-01-11 12:00:36
:LastEditTime: 2021-04-08 18:09:26
:LastEditors: HuangJingCan
@Description: 
"""

from enum import Enum, unique


class TaskType(Enum):
    """
    docstring：任务类型
    """
    # [{"reward_value":0}]
    每日签到 = 1
    # {"satisfy_count":0,"reward_value":0}
    每日参与1次抽盒 = 2
    # {"satisfy_count":0,"reward_value":0}
    每日参与抽盒N次 = 3
    # {"satisfy_count":0,"reward_value":0}
    每日使用1张透视卡 = 4
    # {"satisfy_count":0,"reward_value":0}
    每日使用1张重抽卡 = 5
    # {"satisfy_count":0,"reward_value":0}
    每日使用1张提示卡 = 6
    # {"reward_value":0,"user_num":0,"day_limit_count":0}
    邀请 = 7
    # [{"satisfy_count":0,"reward_value":0}]
    每周参与抽盒N次 = 8
    # [{"satisfy_count":0,"reward_value":0}]
    每周使用N张提示卡 = 9
    # [{"satisfy_count":0,"reward_value":0}]
    每周使用N张透视卡 = 10
    # [{"satisfy_count":0,"reward_value":0}]
    每周使用N张重抽卡 = 11


class PropsCardType(Enum):
    """
    docstring：道具卡类型
    """
    透视卡 = 2
    提示卡 = 3
    重抽卡 = 4


class LogisticsType(Enum):
    """
    docstring:物流类型
    """
    yuantong = "圆通速递"
    yunda = "韵达快递"
    zhongtong = "中通快递"
    youzhengguonei = "邮政快递包裹"
    shunfeng = "顺丰速运"
    huitongkuaidi = "百世快递"
    shentong = "申通快递"
    jd = "京东物流"
    ems = "EMS"
    tiantian = "天天快递"
    youzhengbk = "邮政标准快递"
    debangwuliu = "德邦"
    debangkuaidi = "德邦快递"
    zhaijisong = "宅急送"
    zhongyouex = "众邮快递"
    youshuwuliu = "优速快递"
    baishiwuliu = "百世快运"
    yuantongkuaiyun = "圆通快运"
    yundakuaiyun = "韵达快运"
    annengwuliu = "安能快运"
    zhongtongkuaiyun = "中通快运"



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class CopywritingConfigModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None):
        super(CopywritingConfigModel, self).__init__(CopywritingConfig, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class CopywritingConfig:

    def __init__(self):
        super(CopywritingConfig, self).__init__()
        self.id = 0  # id
        self.act_id = 0  # 活动id
        self.title = ""  # 标题
        self.content = ""  # 内容
        self.copywriting_type = 0  # 文案类型(1问题及帮助配置2关于我们3用户默认发货地址协议4抽盒规则)
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 更新时间

    @classmethod
    def get_field_list(self):
        return ['id', 'act_id', 'title', 'content', 'copywriting_type', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "copywriting_config_tb"
    


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-04-16 14:38:22
:LastEditTime: 2021-03-22 13:45:37
:LastEditors: HuangJianYi
@Description: 
"""
__all__ = ["lottery", "pay", "machine", "home_page", "user", "task", "coin", "prize_order", "buy_order", "coupon", "exchange_order","erp"]
